==> haskell-auto-update-0.1.6-360-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-auto-update.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 auto-update
version:              0.1.6
visibility:           public
id:                   auto-update-0.1.6-JuwzBKpoGZNFHxTEb0Z7WK
key:                  auto-update-0.1.6-JuwzBKpoGZNFHxTEb0Z7WK
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Efficiently run periodic, on-demand actions
description:
    API docs and the README are available at <http://www.stackage.org/package/auto-update>.

category:             Control
abi:                  0e89fefe7574122b0e5f692f88f1d70f
exposed:              True
exposed-modules:
    Control.AutoUpdate Control.Debounce Control.Debounce.Internal
    Control.Reaper

hidden-modules:       Control.AutoUpdate.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-auto-update
hs-libraries:         HSauto-update-0.1.6-JuwzBKpoGZNFHxTEb0Z7WK
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-auto-update/html/auto-update.haddock
haddock-html:         /usr/share/doc/haskell-auto-update/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-auto-update-0.1.6-361-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-auto-update.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 auto-update
version:              0.1.6
visibility:           public
id:                   auto-update-0.1.6-B0AxwjtIMb89PjKoLg2Ti6
key:                  auto-update-0.1.6-B0AxwjtIMb89PjKoLg2Ti6
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Efficiently run periodic, on-demand actions
description:
    API docs and the README are available at <http://www.stackage.org/package/auto-update>.

category:             Control
abi:                  bb355e62dd8aad62b91fceb312015202
exposed:              True
exposed-modules:
    Control.AutoUpdate Control.Debounce Control.Debounce.Internal
    Control.Reaper

hidden-modules:       Control.AutoUpdate.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/auto-update-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-auto-update
hs-libraries:         HSauto-update-0.1.6-B0AxwjtIMb89PjKoLg2Ti6
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-auto-update/html/auto-update.haddock
haddock-html:         /usr/share/doc/haskell-auto-update/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
